@@ -434,7 +434,7 @@ sub get_relationship_type_by_name {
 
 =head2 add_relationship
 
-  Usage    - $ontology->add_relationship()
+  Usage    - $ontology->add_relationship($relationship)
   Returns  - none
   Args     - the relationship (CCO::Core::Relationship) to be added between two existing terms
   Function - adds a relationship between two terms
@@ -664,7 +664,7 @@ sub export {
 		# preambule: OBO header tags
 		print $file_handle "format-version: 1.2\n";
 		print $file_handle "date: ", `date '+%d:%m:%Y %H:%M'`;
-		print $file_handle "default-namespace: cco\n";
+		print $file_handle "default-namespace: CCO\n";
 		print $file_handle "autogenerated-by: onto-perl\n";
 		print $file_handle "remark: The Cell-Cycle Ontology\n";
 	
@@ -690,6 +690,13 @@ sub export {
 	    		croak "The term with id: ", $term->id(), " has no name!" ;
 	    	}
 	    	
+	    	#
+			# alt_id:
+			#
+			foreach my $alt_id ($term->alt_id()) {
+				print $file_handle "\nalt_id: ", $alt_id;
+			}
+	    	
 	    	#
 	    	# builtin:
 	    	#
@@ -737,7 +744,7 @@ sub export {
 	    	# synonym:
 	    	#
 	    	foreach my $synonym ($term->synonym_set()) {
-	    		print $file_handle "\nsynonym: ", $synonym->def_as_string(), " {scope=\"", $synonym->type(), "\"}";
+				print $file_handle "\nsynonym: \"", $synonym->def()->text(), "\" ", $synonym->type(), " ", $synonym->def()->dbxref_set_as_string();
 	    	}
 	    	
 	    	#
@@ -767,15 +774,33 @@ sub export {
 	    	print $file_handle "\ndef: ", $relationship_type->def_as_string() if (defined $relationship_type->def()->text());
 	    	print $file_handle "\ncomment: ", $relationship_type->comment() if (defined $relationship_type->comment());
 	    	foreach my $synonym ($relationship_type->synonym_set()) {
-	    		print $file_handle "\nsynonym: ", $synonym->def_as_string(), " {scope=\"", $synonym->type(), "\"}";
+	    		print $file_handle "\nsynonym: \"", $synonym->def()->text(), "\" ", $synonym->type(), " ", $synonym->def()->dbxref_set_as_string();
 	    	}
+	    	
+	    	#
+	    	# is_a: TODO missing function to retieve the rel types 
+	    	#
+	    	#my $rt = $self->get_relationship_type_by_name("is_a");
+	    	#if (defined $rt)  {
+		    #	my @heads = @{$self->get_head_by_relationship_type($relationship_type, $rt)};
+		    #	foreach my $head (@heads) {
+		    #		if (defined $head->name()) {
+			#    		print $file_handle "\nis_a: ", $head->id(), " ! ", $head->name();
+			#    	} else {
+			#    		croak "The relationship type with id: ", $head->id(), " has no name!" ;
+			#		}
+		    #	}
+	    	#}
+	    	
 	    	print $file_handle "\nis_cyclic: true" if ($relationship_type->is_cyclic() == 1);
 	    	print $file_handle "\nis_reflexive: true" if ($relationship_type->is_reflexive() == 1);
 	    	print $file_handle "\nis_symmetric: true" if ($relationship_type->is_symmetric() == 1);
 	    	print $file_handle "\nis_anti_symmetric: true" if ($relationship_type->is_anti_symmetric() == 1);
 	    	print $file_handle "\nis_transitive: true" if ($relationship_type->is_transitive() == 1);
 	    	print $file_handle "\nis_metadata_tag: true" if ($relationship_type->is_metadata_tag() == 1);
-	    	
+	    	foreach my $xref ($relationship_type->xref_set_as_string()) {
+	    		print $file_handle "\nxref: ", $xref->as_string();
+	    	}
 	    	print $file_handle "\n";
 	    }
     } elsif ($format eq "xml") {
@@ -815,6 +840,13 @@ sub export {
 	    		croak "The term with id: ", $term->id(), " has no name!" ;
 	    	}
 	    	
+	    	#
+			# alt_id:
+			#
+			foreach my $alt_id ($term->alt_id()) {
+				print $file_handle "\t\t<alt_id>", $alt_id, "</alt_id>\n";
+			}
+			
 	    	#
 	    	# def:
 	    	#
@@ -904,6 +936,9 @@ sub export {
 	    	print $file_handle "\t\t<is_anti_symmetric>true</is_anti_symmetric>" if ($relationship_type->is_anti_symmetric() == 1);
 	    	print $file_handle "\t\t<is_transitive>true</is_transitive>" if ($relationship_type->is_transitive() == 1);
 	    	print $file_handle "\t\t<is_metadata_tag>true</is_metadata_tag>" if ($relationship_type->is_metadata_tag() == 1);
+	    	foreach my $xref ($relationship_type->xref_set_as_string()) {
+	    		print $file_handle "\t\t<xref>", $xref->as_string(), "</xref>\n";
+	    	}
 	    	
 	    	print $file_handle "\t</typedef>\n\n";
 	    }
@@ -948,12 +983,19 @@ sub export {
 			# label name = class name
 			#
 			print $file_handle "\t<rdfs:label xml:lang=\"en\">", $term->name(), "</rdfs:label>\n";
+			
+			#
+			# alt_id:
+			#
+			foreach my $alt_id ($term->alt_id()) {
+				print $file_handle "\t<alt_id rdf:datatype=\"http://www.w3.org/2001/XMLSchema#string\">", $alt_id, "</alt_id>\n";
+			}
 				
 			#
 			# xref's
 			#
 			foreach my $xref ($term->xref_set_as_string()) {
-	    			print $file_handle "\t<xref rdf:datatype=\"http://www.w3.org/2001/XMLSchema#string\">", $xref->as_string(), "</xref>\n";
+				print $file_handle "\t<xref rdf:datatype=\"http://www.w3.org/2001/XMLSchema#string\">", $xref->as_string(), "</xref>\n";
 	    	}
 			
 			#
@@ -1094,7 +1136,9 @@ sub export {
 			
 			print $file_handle "\t<is_reflexive rdf:datatype=\"http://www.w3.org/2001/XMLSchema#string\">true</is_reflexive>\n" if ($relationship_type->is_reflexive());
 			print $file_handle "\t<is_anti_symmetric rdf:datatype=\"http://www.w3.org/2001/XMLSchema#string\">true</is_anti_symmetric>\n" if ($relationship_type->is_anti_symmetric()); # anti-symmetric <> not symmetric
-			
+			foreach my $xref ($relationship_type->xref_set_as_string()) {
+	    		print $file_handle "\t<xref rdf:datatype=\"http://www.w3.org/2001/XMLSchema#string\">", $xref->as_string(), "</xref>\n";
+	    	}
 			## There is no way to code these rel's in OBO
 			##print $file_handle "\t<rdf:type rdf:resource=\"&owl;FunctionalProperty\"/>\n" if (${$relationship{$_}}{"TODO"});
 			##print $file_handle "\t<rdf:type rdf:resource=\"&owl;InverseFunctionalProperty\"/>\n" if (${$relationship{$_}}{"TODO"});
@@ -1112,6 +1156,13 @@ sub export {
 		print $file_handle "\t<rdfs:comment rdf:datatype=\"http://www.w3.org/2001/XMLSchema#string\">Describes the reference of the term definition.</rdfs:comment>\n";
 		print $file_handle "</owl:ObjectProperty>\n\n";
 		
+		# alt_id
+		print $file_handle "<owl:DatatypeProperty rdf:ID=\"alt_id\">\n";
+		print $file_handle "\t<rdf:type rdf:resource=\"http://www.w3.org/2002/07/owl#AnnotationProperty\"/>\n";
+		print $file_handle "\t<rdfs:range rdf:resource=\"http://www.w3.org/2001/XMLSchema#string\"/>\n";
+		print $file_handle "\t<rdfs:comment rdf:datatype=\"http://www.w3.org/2001/XMLSchema#string\">", "Defines an alternate id for a term. A term may have any number of alternate ids", "</rdfs:comment>\n";
+		print $file_handle "</owl:DatatypeProperty>\n\n";
+		
 		# xref
 		print $file_handle "<owl:DatatypeProperty rdf:ID=\"xref\">\n";
 		print $file_handle "\t<rdf:type rdf:resource=\"http://www.w3.org/2002/07/owl#AnnotationProperty\"/>\n";
